@@ -5,8 +5,6 @@ import annofabcli.stat_visualization.mask_visualization_dir
 import annofabcli.stat_visualization.merge_visualization_dir
 import annofabcli.stat_visualization.write_performance_rating_csv
 from annofabcli.stat_visualization import (
-    merge_performance_per_date,
-    merge_performance_per_user,
     summarise_whole_performance_csv,
     write_linegraph_per_user,
     write_performance_scatter_per_user,
@@ -22,8 +20,6 @@ def parse_args(parser: argparse.ArgumentParser):
     # サブコマンドの定義
     annofabcli.stat_visualization.mask_visualization_dir.add_parser(subparsers)
     annofabcli.stat_visualization.merge_visualization_dir.add_parser(subparsers)
-    merge_performance_per_date.add_parser(subparsers)
-    merge_performance_per_user.add_parser(subparsers)
     summarise_whole_performance_csv.add_parser(subparsers)
     write_linegraph_per_user.add_parser(subparsers)
     write_performance_scatter_per_user.add_parser(subparsers)
