@@ -805,7 +805,7 @@ def parse_args(parser: argparse.ArgumentParser):
 
     argument_parser.add_project_id()
     parser.add_argument(
-        "--annotation", type=str, help="アノテーションzip、またはzipを展開したディレクトリを指定します。" "指定しない場合はAnnoFabからダウンロードします。"
+        "--annotation", type=str, help="アノテーションzip、またはzipを展開したディレクトリを指定します。" "指定しない場合はAnnofabからダウンロードします。"
     )
 
     parser.add_argument(
